==> ZenTaoPMS.max3.1.php5.4_5.6.zip: zentaopms/extension/max/my/ext/model/class/effort.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPqDYjJP6o0qvfzSW5TP02G9ccVQSRo9tb+a9onFxwUzxz+D7usAS79pwwpX+Psgi/Xg7zr52
bqRRJ+n7oFYPIbRcXg/KkvkZOVA/KXx9TCgfymKrESu12CxbOQi2BbrDycCqSaGVLUWVUummo/dv
vndFKuaCe2KQYmZLIXFsRe5i3b0PcFxKUQ2Jvs/WrYm8GbMB1zAZxPOjmlVf/6I2sUoBUfUZHpl0
SFea36DMLigYRKreRIYtOggt/U3iaM2ZqjxjxAJOifsWiZDT0I8PJvQpBVOd5PnIqkQ3nJxiBC6F
xmtIBJ7pePgUEvtzd2nqMSt0bQn+X7p8V/BvO1fMIj9+9bsVgF/5pH1mWzcz7UhuP+5NRptfaqqb
Ds+wwfKC6qfFCm8XEMEJ7MTcOrt/dQisULwmM7GoxRY33dl8SGM00GDzG2FYUSRcqX+aAv7TRmzM
CFgterQk+QCxIRhrlNRJpZQLjscOVgSGsqtv5L8bWbTIXRVpIke1xVgh08xcjTqf5lWzJMlKTTKs
31Prs6gSWwPrIVy21ZBTRyFQgqBaNp+Rk/Yy5w6SWvDMWn9xrfk7gCXIE0qCOPauGe/iDEJWgEy7
HeLtk7Vso53yimos+0FEV8bbtEhBv/wA5Rm2rwkWNkgqxPztR2ELYOvsLTur4VGVyq6SVHxunScY
WQQAYVtBQClksLAeJLYfxhLQtfiYjMco8Q6u3ad4xiq405fqYnLk0zdNZDeDNhRv9c35Zcg/Ykv0
jbGTQd6h0eDwGAp4J7p1hIGdNG8e+6y3zjqHvn7gUmhwY3rNZBPC/Qih439hwZGgaMZf/wFfrEHu
HTo7pkFAGpC5fFoDiSmzSXyHRrSW5Q9lgTukX1jsv8ccXRYrkG==

==> ZenTaoPMS.max3.4.php5.4_5.6.zip: zentaopms/extension/max/my/ext/model/class/effort.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPrxBIaTr4qzfk7xVPCWjwqWny9E/stYjGIjAa9hYwNUl0+unl4stk2qo0XeZIPtBDZFiRvwO
DukzrRmL7NmExIbPUk7ja3CF1lnNx8u7fS3ES8RTIKLUEJAxwr3I+TyhtJaKwtXF2k4suHX10g5t
lG4t2rfo/JVanaqWKB1wmGh+DeRc574RPR2/ubsS47RQdP3NFfL9XjEMdxKGLEdcD5ExRxTfE+Hd
ZnxUQMtQ9obAVAmUUffp/1uMm/41CB2XRLtbkW793PfskWhEiavNB9/s++ebsQOAbMkFyDquesyT
HpVDfasXsT5fBv5LqWaEYMueRk3+9RzDc+rG0f2X7N6puxrnAaVJ15Hz60RGnxvZ2s2DeOZ9NNMo
mYEJAOieOfkugDMRkfsJVrHiu4Z/SZvBUjqSvAjbUAjQaDlmY3YM/nCMfMpPBsaYHIJsAWzdS3FV
SjlhaupbZcBBw9HzBGd10mdgZWRm61bzCRtdhTMf//fjIJCR76dCzgadFzRU40Db+kVIchovZcFw
b4F6hPfLUogsnFjVAVbv0xqFnBIYHiLevc3OQ+WeKCdUyDaI8v9bIw0NLSk6jSy1Px2B6nQq/qQo
J/a2FWrHqw5G7ihgnPnKh9/lPNkkh+wS0p7GGhCdTkXVh9WXv24DEn3FyUEOhCoEH2j2OnwVXgzl
pFaZkH09jHQYkElNntBiJvXubPOpTnIste6DYJ/TX3LMYSS3L6MbUK3mqFB5kBMX65u7WZrI7lVj
3HrLY67iyhv0JE0VAyurAtTbWL4aCZqg1xciDtNmlH5k1eheUYOqrltD6kZejGuoOYkC8u27tJ6n
wZrP3AyWdGrP1aQIv1Iaf2NH0BEkeWaigL+QaShPjOQmSWa=
